.. include:: ../README.rst


.. toctree::
   :maxdepth: 4
   :hidden:

   readme
   installation
   usage
   contributing
   authors
   history




.. Welcome to Noisy Duck's documentation!
.. ======================================
.. 
.. Contents:
..  
.. .. toctree::
..    :maxdepth: 4
..    :hidden:
.. 
..    readme
..    installation
..    usage
..    contributing
..    authors
..    history
.. 
.. Indices and tables
.. ==================
.. 
.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`
